# -*- coding: utf-8 -*-
PROFILE_ID = 'profile-zest.emailhider:default'


def install_pyproxy(context):
    # This is a new dependency.
    context.runAllImportStepsFromProfile('profile-jquery.pyproxy:default')


def run_kss_step(context):
    context.runImportStepFromProfile(PROFILE_ID, 'kssregistry')


def run_javascript_step(context):
    context.runImportStepFromProfile(PROFILE_ID, 'jsregistry')


def run_browserlayer_step(context):
    context.runImportStepFromProfile(PROFILE_ID, 'browserlayer')



# -*- coding: utf-8 -*-
from plone.app.robotframework.testing import REMOTE_LIBRARY_BUNDLE_FIXTURE
from plone.app.testing import applyProfile
from plone.app.testing import FunctionalTesting
from plone.app.testing import IntegrationTesting
from plone.app.testing import PLONE_FIXTURE
from plone.app.testing import PloneSandboxLayer
from plone.registry.interfaces import IRegistry
from plone.testing import z2
from zope.component import getUtility

import zest.emailhider


class ZestEmailhiderLayer(PloneSandboxLayer):

    defaultBases = (PLONE_FIXTURE,)

    def setUpZope(self, app, configurationContext):
        self.loadZCML(package=zest.emailhider)

    def setUpPloneSite(self, portal):
        applyProfile(portal, 'zest.emailhider:default')
        if portal.hasProperty('email_from_address'):
            # Plone 4
            portal._updateProperty('email_from_address', 'info@example.org')
        else:
            # Plone 5
            registry = getUtility(IRegistry)
            registry['plone.email_from_address'] = 'info@example.org'


ZEST_EMAILHIDER_FIXTURE = ZestEmailhiderLayer()


ZEST_EMAILHIDER_INTEGRATION_TESTING = IntegrationTesting(
    bases=(ZEST_EMAILHIDER_FIXTURE,),
    name='ZestEmailhiderLayer:IntegrationTesting'
)


ZEST_EMAILHIDER_FUNCTIONAL_TESTING = FunctionalTesting(
    bases=(ZEST_EMAILHIDER_FIXTURE,),
    name='ZestEmailhiderLayer:FunctionalTesting'
)


ZEST_EMAILHIDER_ACCEPTANCE_TESTING = FunctionalTesting(
    bases=(
        ZEST_EMAILHIDER_FIXTURE,
        REMOTE_LIBRARY_BUNDLE_FIXTURE,
        z2.ZSERVER_FIXTURE
    ),
    name='ZestEmailhiderLayer:AcceptanceTesting'
)



# -*- coding: utf-8 -*-
"""Setup tests for this package."""
from plone import api
from zest.emailhider.testing import ZEST_EMAILHIDER_INTEGRATION_TESTING

import unittest


class TestSetup(unittest.TestCase):
    """Test that zest.emailhider is properly installed."""

    layer = ZEST_EMAILHIDER_INTEGRATION_TESTING

    def setUp(self):
        """Custom shared utility setup for tests."""
        self.portal = self.layer['portal']
        self.installer = api.portal.get_tool('portal_quickinstaller')

    def test_product_installed(self):
        """Test if zest.emailhider is installed."""
        self.assertTrue(self.installer.isProductInstalled(
            'zest.emailhider'))

    def test_browserlayer(self):
        """Test that IZestEmailhiderLayer is registered."""
        from zest.emailhider.interfaces import (
            IZestEmailHiderLayer)
        from plone.browserlayer import utils
        self.assertIn(IZestEmailHiderLayer, utils.registered_layers())


class TestUninstall(unittest.TestCase):

    layer = ZEST_EMAILHIDER_INTEGRATION_TESTING

    def setUp(self):
        self.portal = self.layer['portal']
        self.installer = api.portal.get_tool('portal_quickinstaller')
        self.installer.uninstallProducts(['zest.emailhider'])

    def test_product_uninstalled(self):
        """Test if zest.emailhider is cleanly uninstalled."""
        self.assertFalse(self.installer.isProductInstalled(
            'zest.emailhider'))
